@@ -242,8 +242,10 @@ class DecoratorBase(object):
     def _get_current_font(self):
         if self.style['font'] is None:
             self.style['font'] = self._load_default_font()
-        else:
+        elif isinstance(self.style['font'], str):
             self.style['font'] = self._load_font()
+        else:
+            pass  # assume self.style['font'] has already been assigned as Font obj. FIXME
 
     def _add_text(self, txt, **kwargs):
         # synchronize kwargs into style
@@ -431,6 +433,9 @@ class DecoratorBase(object):
         # draw object
         draw = self._get_canvas(self.image)
 
+        # check for font object
+        self._get_current_font()
+
         # draw base
         px = (self.style['propagation'][0] +
               self.style['newline_propagation'][0])
@@ -544,6 +549,9 @@ class DecoratorBase(object):
             self._draw_text(draw, (x_, y_), self.style['unit'], **self.style)
 
         if title:
+            # check for font object
+            self._get_current_font()
+
             # calculate position
             tw, th = draw.textsize(title, self.style['font'])
             if is_vertical:
